String (Str)
------------
A string manipulation library.

`Built-in String Functions <https://support.cadence.com/apex/techpubDocViewerPage?path=sklangref/sklangrefIC6.1.8/sklangrefTOC.html>`_

.. dropdown:: Str.ils sourcecode

    .. literalinclude:: ../_static/src/Str.ils
       :language: none
       :linenos:
